@@ -1,5 +1,6 @@
 
 import sqlite3
+from xmlrpc.client import Boolean
 import pymysql
 import sqlparams
 from . import types
@@ -7,7 +8,7 @@ from typing import Any, List
 from dbutils import steady_db
 from urllib.parse import urlparse
 
-def convert_qmark_query_to_adapter_style(query, params, to_format="format"):
+def convert_qmark_query_to_adapter_style(query, params, to_format="format", many:bool=False):
     """
     kongodb uses qmark query style -> '?'
     But some adapter, ie pymysql, supports 'format' style -> '%s'
@@ -17,12 +18,15 @@ def convert_qmark_query_to_adapter_style(query, params, to_format="format"):
         query:str - The query with the qmark
         params:tuple - 
         to_format:str
+        man
 
     Returns:
         tuple(query:str, params:dict|tuple)
     """
     from_format = "qmark"
     _sqlparams = sqlparams.SQLParams(from_format, to_format)
+    if many:
+        return _sqlparams.formatmany(query, params)
     return _sqlparams.format(query, params)
 
 
@@ -37,33 +41,34 @@ class BaseAdapter(object):
     # The engine: sqlite, mysql for (mysql|mariadb), postgresql 
     engine = None
 
-    def execute(self, query: str, params: Any = None) -> Any:
+    def execute(self, query: str, params: Any = None, many:bool = False) -> Any:
         """
         Executes a query
         Args:
             query: str
-            params: tuple()
+            params: tuple() or List(tuple) when many==true
+            many: bool
         
         Returns:
             Cursor
         """
         raise NotImplementedError()
 
-    def create_container(self, table):
+    def create_collection(self, table):
         """
-        Create a container
+        Create a collection
 
         Args:
-            table:str - the container name
+            table:str - the collection name
 
         Returns:
             None
         """
         raise NotImplementedError()
 
-    def drop_container(self, name):
+    def drop_collection(self, name):
         """
-        Drop/Delete a table/container
+        Drop/Delete a table/collection
 
         Returns:
             None
@@ -72,10 +77,10 @@ class BaseAdapter(object):
 
     def get_columns(self, table: str) -> list:
         """
-        Get all static columns in a container
+        Get all static columns in a collection
 
         Args:
-            table: str - container name
+            table: str - collection name
 
         Returns:
             list
@@ -87,14 +92,14 @@ class BaseAdapter(object):
         Get all indexes
 
         Args:
-            table:str - container name
+            table:str - collection name
 
         Returns:
             list
         """
         raise NotImplementedError()
 
-    def get_containers(self) -> list:
+    def get_collections(self) -> list:
         """
         Get all the collections in the DB
 
@@ -105,7 +110,7 @@ class BaseAdapter(object):
 
     def add_columns(self, table, cols_stmt: list):
         """
-        Add columns into container
+        Add columns into collection
 
         Args:
             table: str: table name
@@ -122,10 +127,10 @@ class BaseAdapter(object):
 
     def get_size(self, table) -> int:
         """
-        Get the total entries in the container
+        Get the total entries in the collection
 
         Args:
-            table:str - Container name
+            table:str - collection name
         Returns:
             int
         """
@@ -213,11 +218,14 @@ class SQLiteAdapter(BaseAdapter):
         self.db = sqlite3.connect(file, isolation_level=None)
         self.db.execute('pragma journal_mode=wal')
 
-    def execute(self, query, params={}):
+    def execute(self, query, params={}, many:bool=False):
         with self.db:
-            return self.db.execute(query, params or {})
+            if many is True:
+                return self.db.executemany(query, params)
+            else:
+                return self.db.execute(query, params or {})
 
-    def create_container(self, table):
+    def create_collection(self, table):
         q = "CREATE TABLE IF NOT EXISTS %s (_id VARCHAR(32) PRIMARY KEY, _json TEXT, _created_at TIMESTAMP  NOT NULL DEFAULT '0000-00-00 00:00:00', _modified_at TIMESTAMP NOT NULL DEFAULT '0000-00-00 00:00:00')" % table
         self.execute(q)
 
@@ -248,7 +256,7 @@ class SQLiteAdapter(BaseAdapter):
                 pass
         return self._indexes
 
-    def get_containers(self) -> list:
+    def get_collections(self) -> list:
         q = "SELECT name FROM sqlite_master WHERE type=?"
         res = self.fetchall(q, ('table', ))
         return [item["name"] for item in res]
@@ -319,15 +327,18 @@ class MySQLAdapter(BaseAdapter):
         }
         self.db = steady_db.connect(creator = pymysql, **config)
 
-    def execute(self, query, params={}):
+    def execute(self, query, params={}, many=False):
         with self.db.cursor() as cursor:
             # convert qmark for pymysql
             if params:
-                query, params = convert_qmark_query_to_adapter_style(query, params, 'format')
-            cursor.execute(query, params)
+                query, params = convert_qmark_query_to_adapter_style(query, params, 'format', many=many)
+            if many is True:
+                cursor.executemany(query, params)
+            else:
+                cursor.execute(query, params)
             return cursor
         
-    def create_container(self, table):
+    def create_collection(self, table):
         self.execute("CREATE TABLE IF NOT EXISTS %s (_id VARCHAR(32) PRIMARY KEY, _json JSON, _created_at DATETIME NOT NULL, _modified_at DATETIME NOT NULL)" % table)
 
     def get_columns(self, table: str) -> list:
@@ -341,7 +352,7 @@ class MySQLAdapter(BaseAdapter):
             return [item["Column_name"] for item in self.fetchall("SHOW INDEX FROM %s" % table)]
         except Exception as e: pass
 
-    def get_containers(self) -> list:
+    def get_collections(self) -> list:
         return [list(item.values())[0] for item in self.fetchall("SHOW TABLES")]
 
     def add_columns(self, table, cols_stmt:List[types.BaseType]):
