@@ -352,12 +352,10 @@ class CollectionItem(__Item):
         """
         Select a subcollection
         """
-
         # ensuring constraints
-        collection_info = _CollectionInfo__(self._collection, name)
-        _constraints = collection_info.get_subcollection_constraints(name) or []
+        _constraints = self._collection._meta_collection.get_subcollection_constraints(name) or []
         if constraints and set(constraints) != set(_constraints):
-            collection_info.set_subcollection_constraints(name, constraints)
+            self._collection._meta_collection.set_subcollection_constraints(name, constraints)
             _constraints = constraints
 
         return SubCollection(item=self, name=name, constraints=_constraints)
@@ -437,11 +435,15 @@ class Collection(object):
     DEFAULT_COLUMNS = ["_id", "_json", "_created_at", "_modified_at"]
     _columns = []
     _indexes = []
+    _meta = None 
+    name = None 
+    db = None
 
     def __init__(self, conn: adapters.BaseAdapter, name):
         self.name = name
         self.db = conn
         self.db.create_collection(self.name)
+        self._meta = None
 
     def __len__(self):
         return self.size
@@ -478,6 +480,12 @@ class Collection(object):
         """
         return self.db.get_size(self.name)
 
+    @property
+    def _meta_collection(self):
+        if not self._meta:
+            self._meta = MetaCollection(self.db, self.name)
+        return self._meta 
+
     # ---- methods ----
 
     def get(self, _id: str) -> CollectionItem:
@@ -964,11 +972,11 @@ class SubCollectionItem(__Item):
 
 
 
-class _CollectionInfo__(object):
-    COLLECTION_NAME = "__collections_info__"
+class MetaCollection(object):
+    COLLECTION_NAME = "__collectionsmeta"
 
-    def __init__(self, collection:Collection, collection_name:str):
-        coll = Collection(collection.db, self.COLLECTION_NAME)
+    def __init__(self, db, collection_name:str):
+        coll = Collection(db, self.COLLECTION_NAME)
         coll.add_columns([types.StringType("collection_name", unique=True)])
 
         self.item = coll.find_one({"collection_name": collection_name})
@@ -976,11 +984,11 @@ class _CollectionInfo__(object):
             self.item = coll.add({"collection_name": collection_name})
 
     def get_subcollection_constraints(self, subcollection_name):
-        path = "constraints.%s" % subcollection_name
+        path = "subcollections_constraints.%s" % subcollection_name
         return self.item.get(path) or []
 
     def set_subcollection_constraints(self, subcollection_name, constraints:list):
-        path = "constraints.%s" % subcollection_name
+        path = "subcollections_constraints.%s" % subcollection_name
         if constraints and isinstance(constraints, list):
             return self.item.set(path, constraints)
 
