@@ -32,7 +32,10 @@ QUERY_FILTERING_MAPPER = {
     'endswith': '_is_ends_with',
     'includes': '_is_includes',
     'between': "_is_between",
-    'contains': '_is_contains'
+    'contains': '_is_contains',
+    'exists': '_is_exists',
+    'notexists': '_is_not_exists',
+
 }
 
 # FILTER_OPERATOR:
@@ -49,6 +52,7 @@ SQL_OPERATORS = {
     "between": "BETWEEN ? AND ?",
 }
 
+class _Undefined: pass
 
 """
 DictQuery
@@ -145,7 +149,7 @@ class DictQuery(object):
                         if subdata:
                             for subitem in subdata:
                                 and_check2 |= _matcher._match(
-                                    subitem.get(subpath, None),
+                                    subitem.get(subpath, _Undefined),
                                     query.get('operator'),
                                     query.get('value'),
                                     query.get('case_insensitive')
@@ -155,7 +159,7 @@ class DictQuery(object):
                     # regular query
                     else:
                         and_check &= _matcher._match(
-                            item.get(_qk, None),
+                            item.get(_qk, _Undefined),
                             query.get('operator'),
                             query.get('value'),
                             query.get('case_insensitive')
@@ -308,6 +312,12 @@ class _Matcher(object):
         # TODO: IMPLEMENT
         return False
 
+    def _is_exists(self, data, val=None):
+        return data is not _Undefined
+
+    def _is_not_exists(self, data, val=None):
+        return data is _Undefined
+
 
 
     def _to_lower(self, x, y):
@@ -613,6 +623,17 @@ class Cursor(object):
         """
         return len(self.cursordat)
 
+    def first(self):
+        try:
+            return self.cursordat[0]
+        except KeyError:
+            return None
+
+    def last(self):
+        try:
+            return self.cursordat[:-1]
+        except KeyError:
+            return None
 
 def query(data:list, filters:dict) -> List[dict]:
     return DictQuery(data).execute(filters) if filters and data else data
